%define name    OpenIPMI2
%define version 2.0.6
%define release %mkrel 14

Name: 		%{name}
Summary: 	%{name} - Library interface to IPMI
Version: 	%{version}
Release: 	%{release}
License: 	LGPL
URL: 		http://openipmi.sourceforge.net
Group: 		System/Kernel and hardware
Source: 	OpenIPMI-%{version}.tar.bz2
BuildRequires:	swig >= 1.3
BuildRequires:	python-devel
BuildRequires:	popt-devel
BuildRequires:	ncurses-devel
BuildRequires:	net-snmp-devel
BuildRequires:	libgdbm-devel
BuildRequires:	perl-devel
BuildRequires:	glib2-devel
Conflicts:	OpenIPMI
Requires(pre):	rpm-helper
Requires(post): rpm-helper
Buildroot:      %{_tmppath}/%{name}-%{version}

# Perl is usually installed in /usr/lib, not /usr/lib64 on 64-bit platforms.
#%define perl_libdir %{_exec_prefix}/lib

%description 
This package contains a shared library implementation of IPMI and the
basic tools used with OpenIPMI.

%package	devel
Summary:	Development files for OpenIPMI
Group:		Development/C
Requires:	%{name} = %{version} pkgconfig

%description	devel
Contains additional files need for a developer to create applications
and/or middleware that depends on libOpenIPMI

%package -n	perl-%{name}
Summary:	Perl interface for OpenIPMI
Group:		Development/Perl
Requires:	%{name} = %{version}
Obsoletes:  %{name}-perl

%description -n perl-%{name}
A Perl interface for OpenIPMI.

%package -n	python-%{name}
Summary:	Python interface for OpenIPMI
Group:		Development/Python
Requires:	%{name} = %{version}
Obsoletes:  %{name}-python

%description -n python-%{name}
A Python interface for OpenIPMI.

%package	gui
Summary:	GUI (in python) for OpenIPMI
Group:		System/Kernel and hardware
Requires:	python-%{name} = %{version}-%{release}
Requires:	wxPython >= 2.4.2
Requires:	wxPythonGTK
BuildRequires:	wxPythonGTK

%description	gui
A GUI interface for OpenIPMI.  Written in python an requiring wxWidgets.

%package	ui
Summary:	User Interface (ui)
Group:		System/Kernel and hardware
Requires:	%{name} = %{version}

%description	ui
This package contains a user interface

%package	lanserv
Summary:	Emulates an IPMI network listener
Group:		System/Kernel and hardware
Requires:	%{name} = %{version}

%description	lanserv
This package contains a network IPMI listener.

###################################################
%prep
###################################################
%setup -q -n OpenIPMI-%{version}

###################################################
%build
###################################################
# Disabling the gui
%configure2_5x	--with-wxpython=yes \
		--with-perlinstall=%{perl_vendorarch} \
		--with-pythoninstall=%{python_sitearch} \
		--with-glib12=no
%make

###################################################
%install
###################################################
rm -rf %{buildroot}
%makeinstall_std
install -m755 ipmi.init -D %{buildroot}/%{_sysconfdir}/init.d/ipmi
install -m644 ipmi.sysconf -D %{buildroot}/%{_sysconfdir}/sysconfig/ipmi

###################################################
%preun
###################################################
%_preun_service ipmi

###################################################
%postun
###################################################
/sbin/ldconfig
%_post_service ipmi

%post -p /sbin/ldconfig

%post ui -p /sbin/ldconfig

%postun ui -p /sbin/ldconfig

%post lanserv -p /sbin/ldconfig

%postun lanserv
/sbin/ldconfig

%clean
rm -rf %{buildroot}

###################################################
%files
###################################################
%defattr(-,root,root)
%{_libdir}/libOpenIPMIcmdlang.so.*
%{_libdir}/libOpenIPMIcmdlang.la
%{_libdir}/libOpenIPMIglib.so.*
%{_libdir}/libOpenIPMIglib.la
%{_libdir}/libOpenIPMIposix.so.*
%{_libdir}/libOpenIPMIposix.la
%{_libdir}/libOpenIPMIpthread.so.*
%{_libdir}/libOpenIPMIpthread.la
%{_libdir}/libOpenIPMI.so.*
%{_libdir}/libOpenIPMI.la
%{_libdir}/libOpenIPMIutils.so.*
%{_libdir}/libOpenIPMIutils.la
%{_sysconfdir}/init.d/ipmi
%config(noreplace) %{_sysconfdir}/sysconfig/ipmi
%doc COPYING COPYING.LIB FAQ INSTALL README README.Force
%doc README.MotorolaMXP


###################################################
%files -n perl-%{name}
###################################################
%defattr(-,root,root)
%{perl_vendorarch}/OpenIPMI.pm
%{perl_vendorarch}/auto/OpenIPMI
%doc swig/OpenIPMI.i swig/perl/sample swig/perl/ipmi_powerctl

###################################################
%files -n python-%{name}
###################################################
%defattr(-,root,root)
%{python_sitearch}/*OpenIPMI.*
%doc swig/OpenIPMI.i
%exclude %{python_sitearch}/openipmigui

###################################################
%files gui
###################################################
%defattr(-,root,root)
%{python_sitearch}/openipmigui
%{_bindir}/openipmigui

###################################################
%files devel
###################################################
%defattr(-,root,root)
%{_includedir}/OpenIPMI
%{_libdir}/*.a
%{_libdir}/*.so
%{_libdir}/pkgconfig
%doc doc/IPMI.pdf

###################################################
%files ui
###################################################
%defattr(-,root,root)
%{_bindir}/ipmi_ui
%{_bindir}/ipmicmd
%{_bindir}/openipmicmd
%{_bindir}/ipmish
%{_bindir}/openipmish
%{_bindir}/solterm
%{_bindir}/rmcp_ping
%{_libdir}/libOpenIPMIui.so.*
%{_libdir}/libOpenIPMIui.la
%doc %{_mandir}/man1/ipmi_ui.1*
%doc %{_mandir}/man1/openipmicmd.1*
%doc %{_mandir}/man1/openipmish.1*
%doc %{_mandir}/man1/openipmigui.1*
%doc %{_mandir}/man1/solterm.1*
%doc %{_mandir}/man1/rmcp_ping.1*
%doc %{_mandir}/man7/ipmi_cmdlang.7*
%doc %{_mandir}/man7/openipmi_conparms.7*

###################################################
%files lanserv
###################################################
%defattr(-,root,root)
%{_bindir}/ipmilan
%{_libdir}/libIPMIlanserv.so.*
%{_libdir}/libIPMIlanserv.la
%doc %{_mandir}/man8/ipmilan.8*


%changelog
* Mon Jan 21 2008 Thierry Vignaud <tvignaud@mandriva.com> 2.0.6-14mdv2008.1
+ Revision: 155655
- rebuild for new perl
- kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Wed Sep 19 2007 Guillaume Rousse <guillomovitch@mandriva.org> 2.0.6-13mdv2008.0
+ Revision: 91187
- fix groups
- fix gui package dependencies
- own perl modules directory
- really keep all .so file in devel package, otherwise we get devel dependencies for other packages
- allow gui package
- python macros
- perl and python packages naming policy
- keep .so file in devel package

* Wed Sep 19 2007 Oden Eriksson <oeriksson@mandriva.com> 2.0.6-12mdv2008.0
+ Revision: 90661
- bump release

  + Guillaume Rousse <guillomovitch@mandriva.org>
    - rebuild


* Fri Jan 19 2007 Per Øyvind Karlsen <pkarlsen@mandriva.com> 2.0.6-10mdv2007.0
+ Revision: 110611
- fix group og -devel package (fixes #28150)

* Fri Dec 15 2006 Nicolas Lécureuil <neoclust@mandriva.org> 2.0.6-9mdv2007.1
+ Revision: 97904
- Rebuild against new Python
- Import OpenIPMI2

* Tue Sep 19 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 2.0.6-8mdv2007.0
- Rebuild

* Sat Sep 09 2006 Per Øyvind Karlsen <pkarlsen@mandriva.com> 2.0.6-7mdv2007.0
- move .so symlinks to libraries that's splitted into their own packages
  to the same packages to avoid broken symlinks (fixes #22922)

* Thu Jul 20 2006 Per Øyvind Karlsen <pkarlsen@mandriva.com> 2.0.6-6mdv2007.0
- disable glib 1.2 support (fixes #23533)
- fix no-%%clean-section
- fix non-conffile-in-etc

* Mon Jun 19 2006 Pascal Terjan <pterjan@mandriva.org> 2.0.6-5mdv2007.0
- fix build on x86_64
- add missing / in path to ldconfig (and please rpmlint by using -p if possible)

* Wed Jun 07 2006 Per Øyvind Karlsen <pkarlsen@mandriva.com> 2.0.6-4mdv2007.0
- fix buildrequires
- install perl module in %%{perl_vendorarch}, not %%{perl_sitearch}
- do parallell build
- drop redundant dependencies

* Fri Jun 02 2006 Erwan Velu <velu@seanodes.com> 2.0.6-3mdk
- Fixing buildrequires

* Wed May 31 2006 Erwan Velu <velu@seanodes.com> 2.0.6-1mdk
- Initial mdv release

